"use client";

import React from "react";
import Image from "next/image";
import { FaHome, FaFilm, FaTv, FaListAlt, FaAndroid, FaTelegram } from "react-icons/fa";

const PCHeader: React.FC = () => {
  const menuItems = [
    { id: 1, label: "Home", icon: FaHome, route: "/" },
    { id: 2, label: "Movies", icon: FaFilm, route: "/movies" },
    { id: 3, label: "TV Series", icon: FaTv, route: "/tvshows" },
    { id: 4, label: "My List", icon: FaListAlt, route: "/mylist" },
  ];

  return (
    <header className="fixed top-0 left-0 w-full bg-black bg-opacity-50 backdrop-blur-lg z-50 px-8 py-4 flex justify-between items-center">
      {/* Logo */}
      <div className="flex items-center">
        <Image
          src="/images/menulogo.png"
          alt="Delgor Logo"
          width={140}  // Increased width
          height={100} // Increased height
          className="mr-4"
        />
      </div>

      {/* Menu Items */}
      <nav className="flex items-center space-x-8">
        {menuItems.map((item) => {
          const Icon = item.icon;

          return (
            <a
              key={item.id}
              href={item.route}
              className="flex items-center space-x-2 text-gray-200 hover:text-red-500 transition-all duration-300 ease-in-out"
            >
              <Icon className="text-xl" />
              <span className="text-lg">{item.label}</span>
            </a>
          );
        })}

        {/* Android App Button */}
        <a
          href="https://t.me/delgomoviesdiscussion"
          className="flex items-center space-x-2 px-4 py-2 bg-blue-600 text-white rounded-lg hover:bg-red-700 transition-all duration-300 ease-in-out"
        >
          <FaTelegram className="text-xl" />
          <span className="text-lg">Join Telegram</span>
        </a>
        <a
          href="/downloadapp"
          className="flex items-center space-x-2 px-4 py-2 bg-red-600 text-white rounded-lg hover:bg-red-700 transition-all duration-300 ease-in-out"
        >
          <FaAndroid className="text-xl" />
          <span className="text-lg">Android App</span>
        </a>
      </nav>
    </header>
  );
};

export default PCHeader;
